@@ -20,8 +20,8 @@ from .errors import (
     UserUnverifiedError,
     UserVerifiedError,
 )
-from .metrics import add_span_error, setup_metrics
-from .operations import safe_send_channel
+from .metrics import add_span_error, setup_ignored_errors, setup_metrics
+from .operations import safe_send_user
 from .services import ChannelsService, GuildsService, VerifiesService
 from .settings import Settings
 from .spelltable import generate_link
@@ -66,34 +66,29 @@ class SpellBot(Bot):
 
     async def handle_errors(self, ctx: context.InteractionContext, ex: Exception):
         if isinstance(ex, errors.NoPrivateMessage):
-            return await safe_send_channel(
-                ctx,
+            return await safe_send_user(
+                ctx.author,
                 "This command is not supported via Direct Message.",
-                hidden=True,
             )
         if isinstance(ex, AdminOnlyError):
-            return await safe_send_channel(
-                ctx,
+            return await safe_send_user(
+                ctx.author,
                 "You do not have permission to do that.",
-                hidden=True,
             )
         if isinstance(ex, UserBannedError):
-            return await safe_send_channel(
-                ctx,
+            return await safe_send_user(
+                ctx.author,
                 "You have been banned from using SpellBot.",
-                hidden=True,
             )
         if isinstance(ex, UserVerifiedError):
-            return await safe_send_channel(
-                ctx,
+            return await safe_send_user(
+                ctx.author,
                 "Only unverified users can do that in this channel.",
-                hidden=True,
             )
         if isinstance(ex, UserUnverifiedError):
-            return await safe_send_channel(
-                ctx,
+            return await safe_send_user(
+                ctx.author,
                 "Only verified users can do that in this channel.",
-                hidden=True,
             )
 
         add_span_error(ex)
@@ -125,11 +120,14 @@ class SpellBot(Bot):
     @tracer.wrap(name="interaction", resource="on_message")
     async def on_message(self, message: discord.Message):
         span = tracer.current_span()
+        if span:  # noqa
+            setup_ignored_errors(span)
 
         # handle DMs normally
         if not message.guild or not hasattr(message.guild, "id"):
             return await super().on_message(message)
-        span.set_tag("guild_id", message.guild.id)  # type: ignore
+        if span:  # noqa
+            span.set_tag("guild_id", message.guild.id)  # type: ignore
 
         # ignore everything except messages in text channels
         if (
@@ -137,7 +135,8 @@ class SpellBot(Bot):
             or message.channel.type != discord.ChannelType.text
         ):
             return
-        span.set_tag("channel_id", message.channel.id)  # type: ignore
+        if span:  # noqa
+            span.set_tag("channel_id", message.channel.id)  # type: ignore
 
         # ignore hidden or ephemeral messages
         if message.flags.value & 64:
@@ -148,7 +147,8 @@ class SpellBot(Bot):
             return
 
         message_author_xid = message.author.id  # type: ignore
-        span.set_tag("author_id", message_author_xid)
+        if span:  # noqa
+            span.set_tag("author_id", message_author_xid)
 
         # don't try to verify the bot itself
         if self.user and message_author_xid == self.user.id:  # pragma: no cover
