@@ -2,12 +2,14 @@ import logging
 from typing import Union
 
 import discord
+from ddtrace import tracer
 from discord.ext import commands
 from discord_slash import SlashContext, cog_ext
 from discord_slash.model import SlashCommandOptionType
 
 from .. import SpellBot
 from ..interactions import VerifyInteraction
+from ..metrics import add_span_context
 from ..utils import for_all_callbacks, is_admin
 
 logger = logging.getLogger(__name__)
@@ -31,11 +33,13 @@ class VerifyCog(commands.Cog):
             },
         ],
     )
+    @tracer.wrap(name="interaction", resource="verify")
     async def verify(
         self,
         ctx: SlashContext,
         target: Union[discord.User, discord.Member],
     ):
+        add_span_context(ctx)
         async with VerifyInteraction.create(self.bot, ctx) as interaction:
             await interaction.verify(target=target)
 
@@ -51,11 +55,13 @@ class VerifyCog(commands.Cog):
             },
         ],
     )
+    @tracer.wrap(name="interaction", resource="unverify")
     async def unverify(
         self,
         ctx: SlashContext,
         target: Union[discord.User, discord.Member],
     ):
+        add_span_context(ctx)
         async with VerifyInteraction.create(self.bot, ctx) as interaction:
             await interaction.unverify(target=target)
 
