@@ -18,6 +18,7 @@ from ..errors import (
     UserUnverifiedError,
     UserVerifiedError,
 )
+from ..metrics import setup_ignored_errors
 from ..services import ServicesRegistry, VerifiesService
 from ..utils import user_can_moderate
 
@@ -104,7 +105,10 @@ class BaseInteraction:
         ctx: Optional[InteractionContext] = None,
     ) -> AsyncGenerator[InteractionType, None]:
         interaction = cls(bot, ctx) if ctx else cls(bot)
-        with tracer.trace(name=f"spellbot.interactions.{cls.__name__}.create"):
+        with tracer.trace(  # type: ignore
+            name=f"spellbot.interactions.{cls.__name__}.create",
+        ) as span:
+            setup_ignored_errors(span)
             async with db_session_manager():
                 try:
                     await interaction.upsert_request_objects()
