@@ -10,7 +10,7 @@ from sqlalchemy.orm import relationship
 from sqlalchemy.sql.expression import text
 
 from ..settings import Settings
-from .base import Base, now
+from . import Base, now
 
 if TYPE_CHECKING:  # pragma: no cover
     from . import Channel, Guild, User  # noqa
@@ -268,7 +268,7 @@ class Game(Base):
         return GameFormat(self.format).name.replace("_", " ").title()
 
     def to_embed(self, dm: bool = False) -> discord.Embed:
-        settings = Settings()
+        settings = Settings(self.guild_xid)
         embed = discord.Embed(title=self.embed_title)
         embed.set_thumbnail(url=settings.THUMB_URL)
         embed.description = self.embed_description(dm)
