@@ -1,15 +1,16 @@
+# pylint: disable=wrong-import-order
+
 from typing import Optional
 
 from asgiref.sync import sync_to_async
 from sqlalchemy.dialects.postgresql import insert
 from sqlalchemy.sql.expression import and_
 
-from spellbot.database import DatabaseSession
-from spellbot.models.verify import Verify
-from spellbot.services import BaseService
+from ..database import DatabaseSession
+from ..models import Verify
 
 
-class VerifiesService(BaseService):
+class VerifiesService:
     def __init__(self):
         self.current: Optional[Verify] = None
 
@@ -46,7 +47,7 @@ class VerifiesService(BaseService):
                 and_(
                     Verify.guild_xid == guild_xid,
                     Verify.user_xid == user_xid,
-                )
+                ),
             )
             .one_or_none()
         )
