@@ -1,11 +1,12 @@
+# pylint: disable=wrong-import-order
+
 from asgiref.sync import sync_to_async
 
-from spellbot.database import DatabaseSession
-from spellbot.models.watch import Watch
-from spellbot.services import BaseService
+from ..database import DatabaseSession
+from ..models import Watch
 
 
-class WatchesService(BaseService):
+class WatchesService:
     @sync_to_async
     def fetch(self, guild_xid: int) -> list[dict]:
         watches = (
